#!/bin/sh

RAMDISK="/usr/ramdisk"
if [ -f ${RAMDISK}/PG.conf ]; then
	. ${RAMDISK}/PG.conf
	PGPATH="${RAMDISK}"
else
	. /etc/PG.conf
fi

. ${PGPATH}/etc/panabit.inf

PGBIN=${PGPATH}/bin
FLOWEYE=${PGBIN}/floweye
EVENTFILE=${PGETC}/log/pending_events
SYSNAME=`cat /usr/ramdisk/etc/sysname.inf`
APPWEBROOT="/cgi-bin/app/"
if [ -e /usr/ramdisk/datalog/keepme ]; then
	RAMLOG="/usr/ramdisk/datalog"
else
	RAMLOG="${DATAPATH}"
fi

afm_dialog_msg()
{
    echo "<script language=javascript>"
    echo "alert(\"$1\");"
    echo "</script>"
}

afm_window_close()
{
    echo "<script language=javascript>"
    echo "window.close();"
    echo "</script>"
}

cgi_print_mod_header()
{
        local width

        width=$2
        [ "${width}" = "" ] && width=700
        echo "<div style=\"width:${width};height:28;border-bottom:1px solid #e0e0e0;\">"
	echo "<ul class=\"nav nav-tabs\">"

        for capurl in ${MOD_TAB_LIST}
        do
                cap=`echo ${capurl} | cut -d'#' -f1`
                url=`echo ${capurl} | cut -d'#' -f2`
                if [ "${cap}" = "$1" ]; then
                        echo "<li class=active><a href=\"${url}\">${cap}</a></li>"
                else
                        echo "<li><a href=\"${url}\">${cap}</a></li>"
                fi
        done
        echo "</ul>"
	echo "</div>"
}


# redirect current page to the designated page
# @param arg1 time to wait
# @param arg2 url of the designated page
# @return 
afm_load_page()
{
    echo "<META HTTP-EQUIV=REFRESH CONTENT=\"$1;URL=$2\">"
}

# to see if arg1 is digit number
# @param arg1
# @return 1(yes), 0(no)
afm_isdigit()
{
	local ret=""

	ret=`echo $1 | sed -e "s/[0-9]//g"`
	[ "${ret}" = "" -o "${ret}" = "-" ] && return 1
	return 0
}

# @param arg1 the number
# @param arg2 begin number
# @param arg3 end number
# @return 1(yes) 0(no)
afm_isbetween()
{
	local ret=""

	ret=`echo $1 | sed -e "s/[0-9]//g"`
	[ "${ret}" != "" -a "${ret}" != "-" ] && return 0
	
	[ $1 -ge $2 -a $1 -le $3 ] && return 1
	return 0
}

# to see if arg1 is an IP address
# @param arg1
# @return 1(yes), 0(no)
afm_isipaddr()
{
	local v=""

	v=`echo $1 | cut -d'.' -f1`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f2`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f3`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f4`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f5`
	[ "$v" != "" ] && return 0

	return 1 
}

cgi_show_title()
{
	curtime=`date +%s`
	boottime=`sysctl -n kern.boottime | cut -d',' -f1 | cut -d'=' -f2`
	boottime=$((${curtime} - ${boottime}))
	bootday=$((${boottime} / 86400))
	dayhour=$((${bootday} * 24))
	boothour=$((${boottime} / 3600))
	boothour=$((${boothour} - ${dayhour}))
	bootsec=$((${boottime} % 3600))
	bootmin=$((${bootsec} / 60))
	bootsec=$((${boottime} % 60))

	width="$2"
	[ "${width}" = "" ] && width=700

	echo "<table class=title width=${width} style=\"border-bottom:1px dotted #185a73\">"
	echo "<tr><td><b>$1</b></td><td style=\"font-size:12px;color:#185A73\" align=right width=*>${bootday}${boothour}Сʱ${bootmin}${bootsec}"
	if [ -f ${DATAPATH}/panaos.core ]; then
		echo "(<a style=\"color:#0000ff\" href=\"javascript:showDump()\"><b>${SYSNAME}crash)</b></a>"
	else
		if [ "${SYSNAME}" = "" ]; then
			echo "(${PANABIT_USER})"
		else
			echo "<b style=\"color:#ff0000\">[&nbsp;${SYSNAME}&nbsp]</b>"
		fi
	fi
	echo "</td></tr></table>"
}

cgi_show_iptype()
{
        local anyselect=""
        local netselect=""
        local rngselect=""

        case "$1" in
        "any")
                anyselect="selected"
                ;;
        "net")
                netselect="selected"
                ;;
        "iprange")
                rngselect="selected"
                ;;
	"range")
                rngselect="selected"
                ;;
        esac

        echo "<option value=\"any\" ${anyselect}>ַ</option>"
        echo "<option value=\"net\" ${netselect}>xxx.xxx.xxx.xxx/nn</option>"
        echo "<option value=\"range\" ${rngselect}>n.n.n.n-m.m.m.m</option>"

        if [ "${tblexists}" != "" ]; then
                if [ "$1" = "table" ]; then
                        echo "<option value=\"table\" selected>IPȺ</option>"
                else
                        echo "<option value=\"table\">IPȺ</option>"
                fi
        fi
}

cgi_show_usrgrp()
{
	local idname=$1
	local gid

	${FLOWEYE} pppoeippool list | while read pid pname start end theothers
	do
		[ "${start}" = "0.0.0.0" -a "${end}" = "0.0.0.0" ] && continue;
		if [ "${idname}" = "pppoe.${pid}" -o "${idname}" = "${pname}" ]; then
			echo "<option value=\"pppoe.${pid}\" selected>${pname}</option>"
		else
			echo "<option value=\"pppoe.${pid}\">${pname}</option>"
		fi
	done
}

operator_check()
{
	local url=$1
	local user=$2

	[ "${user}" = "" ] && user=${ADMIN_NAME}
	if [ "${PANABIT_USER}" != "${ADMIN_NAME}" -a "${PANABIT_USER}" != "${user}" ]; then
		afm_dialog_msg "Ȩ޲!"
		afm_load_page 0 "${url}"
		exit 0
	fi
}

cgi_show_app_info()
{
	local appid="$1"
	local width=$2
	local nameval

	wid8=$((${width} / 8))
	wid4=$((${width} / 4))	

	output=`${FLOWEYE} app get ${CGI_appid}`
	if [ "${output}" != "" ]; then
		for nameval in ${output}; do
        		eval "${nameval}"
		done
	fi

	echo "<table width=${width} border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr height=22>
    <td width=${wid8} align=center></td>
    <td width=${wid8} align=center>ڵ</td>
    <td width=${wid4} align=center>(/)</td>
    <td width=${wid4} align=center>(/)</td>
    <td width=* align=center>(/)</td>
</tr>
<tr id=row1 height=22>
        <td align=right>${flowcnt}</td>
        <td align=right>${nodecnt}</td>
        <td align=right>${upbytes}/${downbytes}</td>
        <td align=right>${upbps}/${downbps}</td>
        <td align=right>${nat_upbps}/${nat_downbps}</td>
</tr>
</table>"
}

cgi_show_ipobj_info()
{
	local usrname;

	if [ "${upool}" != "" ]; then
		usrname="${upool}/${nbname}"
	else
		usrname="${nbname}"
	fi

	echo "<table width=800 border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr>
        <td width=160 align=right>˺Ϣ</td>
        <td width=130 align=right>MACַ</td>
        <td width=120 align=right>ۼ</td>
        <td width=120 align=right>ۼ</td>
        <td width=120 align=right>bps</td>
        <td width=*   align=right>bps</td>
</tr>
<tr id=row5>
        <td align=right>${usrname}</td>
        <td align=right>${mac}</td>
        <td align=right id=ipoutbytes>${outbytes}</td>
        <td align=right id=ipinbytes>${inbytes}</td>
        <td align=right id=ipbpsout>${bpsout}</td>
        <td align=right id=ipbpsin>${bpsin}</td>
</tr>
</table>

<table width=800 border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr>
        <td width=160 align=right>(/,kbps)</td>
        <td width=130 align=right>ʱ()</td>
        <td width=120 align=right></td>
        <td width=120 align=right></td>
        <td width=120 align=right>(IE/CH/Ȩ)</td>
        <td width=*   align=right>ƶն</td>
</tr>
<tr id=row1>
        <td align=right>${ratein}/${rateout}</td>
        <td align=right id=iplifetime>${life_tmstr}</td>
        <td align=right id=ipflowcnt>${flowcnt}</td>
        <td align=right id=ipqqcnt>${qqcnt}/${accountcnt}</td>
        <td align=right id=ipcookie>${iecookie}/${chromecookie}/${weightcookie}</td>
       	<td align=right id=ipmstcnt>${mstcnt}</td>
</tr>
</table>"
}

WEB_LOGGER()
{
	local logfile
	local curtime

	if [ -e /usr/ramdisk/datalog/keepme ]; then
		localfile="/usr/ramdisk/datalog/web_`date +%Y.%m.%d`.log"
	else
		localfile="${DATAPATH}/web_`date +%Y.%m.%d`.log"
	fi

	curtime=`date +%Y.%m.%d/%H:%M:%S`
	echo "${curtime} ${REMOTE_ADDR} ${PANABIT_USER} $1 $2" >> ${localfile}
	sync
	sync
}

string_verify()
{
	local errmsg
	local sysname="$1"

        # verify it
        errmsg=`echo ${sysname} | grep "[&|\||>|-|(|)]"`
        [ "${errmsg}" != "" ] && return 0

	errmsg=`echo ${CGI_sysname} | grep "\.conf"`
	[ "${errmsg}" != "" ] && return 0

	return 1
}

cgi_show_iftablist()
{
	echo "ǰ״̬#/cgi-bin/Monitor/if_show?name=$1 ʵʱ#/cgi-bin/Monitor/ifpxy_rtgraph?name=$1 ʷ#/cgi-bin/Monitor/if_graph?time=day&name=$1"
}

cgi_show_pxytablist()
{
	if [ "${type}" = "" ]; then
		for nameval in `${FLOWEYE} nat getproxy $1`
		do
        		eval "${nameval}"
		done
	fi

	if [ "${type}" = "rtif" ]; then
        	echo "#/cgi-bin/Route/iflan_edit?iflanname=$1 DHCP#/cgi-bin/Route/dhcpsvr_edit?id=$1 ǰ״̬#/cgi-bin/Monitor/proxy_show?proxyname=$1 \
ʷ#/cgi-bin/Monitor/proxy_graph?time=day&proxyname=$1 ·־#/cgi-bin/Monitor/proxy_logshow?proxyname=$1"
	elif [ "${type}" = "posvrif" ]; then
        	echo "#/cgi-bin/Pppoe/pppoesvr_edit?name=$1 ǰ״̬#/cgi-bin/Monitor/proxy_show?proxyname=$1 \
ʷ#/cgi-bin/Monitor/proxy_graph?time=day&proxyname=$1 ·־#/cgi-bin/Monitor/proxy_logshow?proxyname=$1"
	else
        	echo "#/cgi-bin/Route/proxy_edit?proxyname=$1 ǰ״̬#/cgi-bin/Monitor/proxy_show?proxyname=$1 \
ʵʱ#/cgi-bin/Monitor/proxy_rtgraph?name=$1&type=${type} TOPӦ#/cgi-bin/Monitor/proxy_apprate?link=$1 \
ʷ#/cgi-bin/Monitor/proxy_graph?time=day&proxyname=$1 ·־#/cgi-bin/Monitor/proxy_logshow?proxyname=$1"
	fi
}

TMPPATH=${PGPATH}/admin/tmp
MAXPRI=6
ADMIN_NAME="admin"
[ "${TOPSEC}" != "" ] && ADMIN_NAME="superman"

#
# Show CGI header
#
echo "<html xmlns:v=\"urn:schemas-microsoft-com:vml\" xmlns:o=\"urn:schemas-microsoft-com:office:office\">
<head><title>${CGI_browsertitle}</title>
<link href=\"/img/p2p.css\" type=\"text/css\" rel=\"stylesheet\">
<meta http-equiv=\"Content-Type\" content=\"text/html; charset=gb2312\">
<META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
<META HTTP-EQUIV=\"Cache-Control\" content=\"no-cache\">
</head><script type="text/javascript" src="/img/showdump.js"></script>"
